Function print

pub fn print(ast_root: &AstRoot, metadata: &AstMetadata, driver: &mut Driver)
Prints the AST.

By default, the printer prints the AST to stdout.

There are some undocumented compiler flags which allows the printer to print to a text file instead. We use these flags in the integration tests when testing the AST printer.

Pass -fredirect_stdout -fredirect_file=output_file.txt to print to output_file.txt.